pyargcbr package
================

Subpackages
-----------

.. toctree::

    pyargcbr.agents
    pyargcbr.cbrs
    pyargcbr.configuration
    pyargcbr.knowledge_resources

Submodules
----------

pyargcbr.pyargcbr module
------------------------

.. automodule:: pyargcbr.pyargcbr
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyargcbr
    :members:
    :undoc-members:
    :show-inheritance:
